/*
 * @(#)FakeSheetWindowListener.java
 *
 * Copyright (c) 2008 Jeremy Wood. All Rights Reserved.
 *
 * You have a non-exclusive, royalty free, license to use,
 * modify and redistribute this software in source and binary code form,
 * provided that i) this copyright notice and license appear on all copies of
 * the software; and ii) You do not utilize the software in a manner
 * which is disparaging to the original author.
 *
 * This software is provided "AS IS," without a warranty of any kind. ALL
 * EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND WARRANTIES, INCLUDING ANY
 * IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR
 * NON-INFRINGEMENT, ARE HEREBY EXCLUDED. THE AUTHOR SHALL NOT BE
 * LIABLE FOR ANY DAMAGES SUFFERED AS A RESULT OF USING, MODIFYING
 * OR DISTRIBUTING THE SOFTWARE OR ITS DERIVATIVES. IN NO EVENT WILL THE
 * AUTHOR BE LIABLE FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT,
 * INDIRECT, SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER
 * CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF THE USE OF
 * OR INABILITY TO USE SOFTWARE, EVEN IF THE AUTHOR HAS BEEN ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGES.
 */
package com.bric.swing.toolbar;

import java.awt.Point;
import java.awt.Rectangle;
import java.awt.Window;
import java.awt.event.ComponentEvent;
import java.awt.event.ComponentListener;
import javax.swing.JComponent;
import javax.swing.SwingUtilities;


/** <P>This listens to the parent window and makes important
 * changes to the child window to best emulate a "sheet-like"
 * dialog.
 * <P>If the parent is resized: then the dialog needs to
 * be repositioned and the modal cover needs to be resized.
 * <P>When the parent window is dragged, this drags the other window
 * an identical (+dx, +dy).
 * <P>This class is flawed, though, because on Mac the
 * componentResized events are coalesced together, and therefore
 * the second window moves in spurts and jumps.  But I don't see
 * how else to implement this without actual sheets.
 */
class FakeSheetWindowListener implements ComponentListener {
	Point lastLocation;
	Window window1, window2;
	JComponent modalCover, dialogAnchor;
	public FakeSheetWindowListener(Window window1,Window window2,JComponent dialogAnchor,JComponent modalCover) {
		lastLocation = window1.getLocation();
		this.window1 = window1;
		this.window2 = window2;
		this.modalCover = modalCover;
		this.dialogAnchor = dialogAnchor;
	}
	
	public void componentHidden(ComponentEvent e) {}

	public void componentMoved(ComponentEvent e) {
		Point newLocation = window1.getLocation();
		
		translate(window2,newLocation.x-lastLocation.x,
				newLocation.y-lastLocation.y);
		
		lastLocation = newLocation;
	}
	
	/** Translate a window (+dx, +dy) */
	public static void translate(Window w,int dx,int dy) {
		Point p = w.getLocation();
		p.x += dx;
		p.y += dy;
		w.setLocation(p);
	}

	public void componentResized(ComponentEvent e) {
		modalCover.setSize(window1.getSize());
		repositionDialog();
	}
	
	protected void repositionDialog() {
		Point topLeft = new Point(0,0);
		topLeft = SwingUtilities.convertPoint(dialogAnchor, topLeft, window1);
		Rectangle optionsBounds = new Rectangle( dialogAnchor.getWidth()/2-window2.getWidth()/2+window1.getX(),
				topLeft.y+dialogAnchor.getHeight()+5+window1.getY(),
				window2.getWidth(),window2.getHeight());
		SwingUtilities.convertRectangle(dialogAnchor, optionsBounds, window1);
		window2.setBounds(optionsBounds);
	}

	public void componentShown(ComponentEvent e) {
	}
}