/*
 * Copyright (c) 2010, Franziska Hufsky
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  * Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *  * Neither the name of the Friedrich-Schiller-University Jena nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package de.unijena.bioinf.labelingdetector.ui;

import com.jgoodies.forms.builder.DefaultFormBuilder;
import de.randgestalten.bean.AbstractBean;
import de.unijena.bioinf.labelingdetector.Molecule;
import de.unijena.bioinf.labelingdetector.MoleculeSettings;
import epos.ui.util.BindingUtils;
import epos.ui.util.ComponentUtils;

import javax.swing.*;

/**
 * Date: 28-Jun-2010
 *
 * @author Thasso Griebel (thasso.griebel@gmail.com)
 */
public class MoleculeSettingsPanel extends AbstractBean{

    public enum Labeling{N15("N15", MoleculeSettings.Labeling.N15), C13("C13", MoleculeSettings.Labeling.C13), O17("O17", MoleculeSettings.Labeling.O17);
        private String name;
        private MoleculeSettings.Labeling labeling;

        Labeling(String name, MoleculeSettings.Labeling labeling) {

            this.name = name;
            this.labeling =labeling;
        }

        public MoleculeSettings.Labeling getLabeling() {
            return labeling;
        }

        @Override
        public String toString() {
            return name;
        }
    }

    public enum CarbonRatio{bio("biological (1.096%)", MoleculeSettings.CarbonRatio.bio), carbonate("carbonate specific (1.112%)", MoleculeSettings.CarbonRatio.carbonate);
        private String name;
        private MoleculeSettings.CarbonRatio ratio;

        CarbonRatio(String name, MoleculeSettings.CarbonRatio ratio){
            this.name =name;
            this.ratio=ratio;
        }

        public MoleculeSettings.CarbonRatio getCarbonRatio(){
            return ratio;
        }

        @Override
        public String toString(){
             return name;
        }
    }

    private Labeling labeling = Labeling.N15;
    private CarbonRatio carbonRatio = CarbonRatio.bio;
    private int charge = 1;
    private String sumformula = "";
    private String modification="";

    public Labeling getLabeling() {
        return labeling;
    }

    public void setLabeling(Labeling labeling) {
        firePropertyChange("labeling", this.labeling, this.labeling = labeling);
    }

    public CarbonRatio getCarbonRatio(){
         return carbonRatio;
    }

    public void setCarbonRatio(CarbonRatio carbonRatio){
        firePropertyChange("ratio", this.carbonRatio, this.carbonRatio=carbonRatio);
    }

    public int getCharge() {
        return charge;
    }

    public void setCharge(int charge) {
        firePropertyChange("charge", this.charge, this.charge = charge);
    }

    public String getSumformula() {
        return sumformula;
    }

    public void setSumformula(String sumformula) {
        firePropertyChange("sumformula", this.sumformula, this.sumformula = sumformula);
    }

    public String getModification(){
        return modification;
    }

    public void setModification(String modification){
        firePropertyChange("modification", this.modification, this.modification=modification);
    }

    public JComponent getComponent(){

        // components
        JComboBox elementBox = ComponentUtils.createComboBox(Labeling.values(), Labeling.N15);
        JSpinner chargeBox = ComponentUtils.createSpinner(1, 1, 5, 1);
        JTextField moleculeField = ComponentUtils.createTextFieldPrompt("Sum formula");
        JTextField modificationField = ComponentUtils.createTextField();
        JComboBox ratioBox = ComponentUtils.createComboBox(CarbonRatio.values(), CarbonRatio.bio);

        // layout
        DefaultFormBuilder builder = ComponentUtils.formBuilder();
     
        
        builder.append("Labeling", elementBox);            
        builder.append("Charge", chargeBox);
        builder.append("Sum formula", moleculeField);
        builder.append("Unlabeled part", modificationField);
        builder.append("C13/C12 ratio", ratioBox);

        // logic
        BindingUtils.bindReadWrite(this, "labeling", elementBox, "selectedItem").bind();
        BindingUtils.bindReadWrite(this, "charge", chargeBox, "value").bind();
        BindingUtils.bindReadWrite(this, "sumformula", moleculeField, "text").bind();
        BindingUtils.bindReadWrite(this, "modification", modificationField,"text").bind();
        BindingUtils.bindReadWrite(this, "carbonRatio", ratioBox, "selectedItem").bind();

        return builder.getPanel();
    }

    public static void main(String[] args) {
        JFrame f = new JFrame();
        f.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        f.setContentPane(new MoleculeSettingsPanel().getComponent());
        f.pack();
        f.setVisible(true);
    }

    public Molecule getConvertedMolecule() {
        if (getModification().equals("")){
            return new Molecule(getSumformula(), getCharge());
        }
        return new Molecule(getSumformula(),getModification(),getCharge());
    }

    


}
