/*
 * Copyright (c) 2010, Franziska Hufsky
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  * Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *  * Neither the name of the Friedrich-Schiller-University Jena nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package de.unijena.bioinf.labelingdetector.ui;

import de.unijena.bioinf.labelingdetector.Peak;
import de.unijena.bioinf.labelingdetector.Spectrum;

import java.io.*;
import java.util.ArrayList;
import java.util.List;

/**
 * Date: 28-Jun-2010
 *
 * @author Thasso Griebel (thasso.griebel@gmail.com)
 */
public class Utils {

    //SPECTRUM FORMAT:
    // Peak Intensity
    // Peak Intensity
    // ...
    // several spectra can be devided by ***

    public static List<AnalysedSpectrum> readInputSpectra(String input){
        List<AnalysedSpectrum> inputSpectra = new ArrayList<AnalysedSpectrum>();

        String[] lines = input.split("\n");
        List<Peak> peaks = new ArrayList<Peak>();
        int c=0;
        String info="";
        for (int i=0; i<lines.length; i++){
            String line = lines[i];
            if (line.contains("*")){
                if (!peaks.isEmpty()){
                    Spectrum s = new Spectrum(peaks);
                    AnalysedSpectrum as = new AnalysedSpectrum(c,info,s); c++;
                    inputSpectra.add(as);
                }
                peaks=new ArrayList<Peak>();
                info=line.substring(line.lastIndexOf("*")+1);
                info=info.trim();
            }else{
                String[] peakSplit = line.split("\t");
                if (peakSplit.length>1){
                    try{
                        double mass = Double.parseDouble(peakSplit[0]);
                        double intensity = Double.parseDouble(peakSplit[1]);
                        Peak p = new Peak(mass, intensity);
                        peaks.add(p);
                    }catch(NumberFormatException e){

                    }
                }

            }
        }
        //last spectrum
        if (!peaks.isEmpty()){
            Spectrum s = new Spectrum(peaks);
            AnalysedSpectrum as = new AnalysedSpectrum(c,info,s);
            inputSpectra.add(as);
        }

        return inputSpectra;
    }

    public static List<AnalysedSpectrum> readInputSpectra(File file){
        List<AnalysedSpectrum> inputSpectra = new ArrayList<AnalysedSpectrum>();

        try {
            BufferedReader breader = new BufferedReader(new FileReader(file));
            List<Peak> peaks = new ArrayList<Peak>();
            String line = breader.readLine();
            String info ="";
            int c=0;
            while(line!=null){
                if (line.contains("*")){
                    if (!peaks.isEmpty()){
                        Spectrum s = new Spectrum(peaks);
                        AnalysedSpectrum as = new AnalysedSpectrum(c,info,s); c++;
                        inputSpectra.add(as);
                    }
                    peaks=new ArrayList<Peak>();
                    info=line.substring(line.lastIndexOf("*")+1);
                    info=info.trim();
                }else{
                    String[] peakSplit = line.split("\t");
                    if (peakSplit.length>1){
                        try{
                            double mass = Double.parseDouble(peakSplit[0]);
                            double intensity = Double.parseDouble(peakSplit[1]);
                            Peak p = new Peak(mass, intensity);
                            peaks.add(p);
                        }catch(NumberFormatException e){

                        }
                    }

                }
                line=breader.readLine();
            }
            //last spectrum
            if (!peaks.isEmpty()){
                Spectrum s = new Spectrum(peaks);
                AnalysedSpectrum as = new AnalysedSpectrum(c,info,s);
                inputSpectra.add(as);
            }
        } catch (FileNotFoundException e) {
                e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
        } catch (IOException e) {
            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
        }


        return inputSpectra;
    }

}
