/*
 * Copyright (c) 2010, Franziska Hufsky
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  * Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *  * Neither the name of the Friedrich-Schiller-University Jena nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package de.unijena.bioinf.labelingdetector.ui.wizard;

import com.jgoodies.forms.builder.DefaultFormBuilder;
import de.unijena.bioinf.labelingdetector.ui.AnalysedSpectrum;
import epos.ui.util.ComponentUtils;
import epos.ui.wizard.AbstractWizardPanel;
import epos.ui.wizard.WizardPanel;
import epos.ui.wizard.panels.FileSavePanel;

import javax.swing.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.util.List;

/**
 * Date: 28-Jun-2010
 *
 * @author Thasso Griebel (thasso.griebel@gmail.com)
 */
public class SelectImporterPanel extends AbstractWizardPanel implements ActionListener {
    private JPanel main;
    private JRadioButton clip;
    private JRadioButton file;
    private CopyFromclipboardPanel clipBoardPanel;
    private FileSavePanel filePanel;

    public SelectImporterPanel() {
        super("Select Input", "Choose whether to copy the spectra from clipboard or to upload a file.");
    }

    public JComponent getComponent() {
        if(main == null){
            clip = ComponentUtils.createRadioButton("");
            file = ComponentUtils.createRadioButton("");

            clip.addActionListener(this);
            clip.setSelected(true);
            ButtonGroup group = new ButtonGroup();
            group.add(clip);group.add(file);

            DefaultFormBuilder b = ComponentUtils.formBuilder();
            b.append("Text input", clip);
            b.append("File", file);
            this.main = b.getPanel();
        }
        return main;
    }

    @Override
    public WizardPanel getNext() {
        if(clip.isSelected()) {
            if(clipBoardPanel == null)
                clipBoardPanel = new CopyFromclipboardPanel();
            return clipBoardPanel;
        }else{
            if(filePanel == null){
                filePanel = new FileSavePanel("Select a file", "Please select a file containing at least one spectrum.\nSeveral spectra should be separated by ***(info)");
                filePanel.setUseOpenDialog(true);
            }
            return filePanel;
        }        
    }

    public File getFile(){
        if (file.isSelected()){
             if (filePanel==null)return null;
            return filePanel.getFile();
        }
        return null;
    }

    public List<AnalysedSpectrum> getSpectra(){
        if (clip.isSelected()){
            if(clipBoardPanel == null) return null;
            return clipBoardPanel.getSpectra();
        }
        return null;

    }

    public void actionPerformed(ActionEvent e) {
        wizard.validate();
    }
}
